@@ -1,6 +1,6 @@
 package Data::Dump::OneLine;
 BEGIN {
-  $Data::Dump::OneLine::VERSION = '0.01';
+  $Data::Dump::OneLine::VERSION = '0.02';
 }
 # ABSTRACT: Use Data::Dump to produce dumps that fit in one line
 
@@ -11,11 +11,11 @@ use Data::Dump;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(dump_oneline dump1);
+our @EXPORT_OK = qw(dump_oneline dump_one_line dump1);
 
 
 
-sub dump_oneline {
+sub dump_one_line {
     local $_ = Data::Dump::dump(@_);
 
     s/^\s*#.*//mg; # comments
@@ -29,7 +29,11 @@ sub dump_oneline {
 1;
 
 
-sub dump1 { dump_oneline(@_) }
+sub dump1 { dump_one_line(@_) }
+
+
+# old spelling
+sub dump_oneline { dump_one_line(@_) }
 
 
 __END__
@@ -41,14 +45,14 @@ Data::Dump::OneLine - Use Data::Dump to produce dumps that fit in one line
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
- use Data::Dump::OneLine qw(dump_oneline dump1);
+ use Data::Dump::OneLine qw(dump_one_line dump1);
 
  # just use like Data::Dump's dump()
- dump_oneline(...);
+ dump_one_line(...);
 
 =head1 DESCRIPTION
 
@@ -58,14 +62,16 @@ code, etc.
 
 =head1 FUNCTIONS
 
-=head2 dump_oneline(...)
+=head2 dump_one_line(...)
 
-Dump one or more data structures on a single line. Uses L<Data::Dump::Filtered>
-as the backend.
+Dump one or more data structures on a single line. Uses L<Data::Dump> as the
+backend.
 
 =head2 dump1
 
-An alias for dump_oneline().
+An alias for dump_one_line().
+
+=for Pod::Coverage (dump_oneline)
 
 =head1 SEE ALSO
 
